pub struct client_disconnected { /* private fields */ }Trait Implementations
Sourceimpl FnInfo for client_disconnected
impl FnInfo for client_disconnected
Sourcetype FnKind = FnKindReducer
type FnKind = FnKindReducer
The function kind, which will cause scheduled tables to accept reducers.
Sourceconst LIFECYCLE: Option<LifecycleReducer>
const LIFECYCLE: Option<LifecycleReducer>
The lifecycle of the function, if there is one.
Sourceconst ARG_NAMES: &'static [Option<&'static str>]
const ARG_NAMES: &'static [Option<&'static str>]
A description of the parameter names of the function.
Sourcetype Invoke = fn(ReducerContext, &[u8]) -> Result<(), Box<str>>
type Invoke = fn(ReducerContext, &[u8]) -> Result<(), Box<str>>
The type of function to invoke.
Sourcefn return_type(_ts: &mut impl TypespaceBuilder) -> Option<AlgebraicType>
fn return_type(_ts: &mut impl TypespaceBuilder) -> Option<AlgebraicType>
The return type of this function.
Currently only implemented for views.