#[non_exhaustive]pub struct user__TableHandle {}Trait Implementations
Sourceimpl Table for user__TableHandle
impl Table for user__TableHandle
Sourcetype UniqueConstraintViolation = UniqueConstraintViolation
type UniqueConstraintViolation = UniqueConstraintViolation
The error type for this table for unique constraint violations. Will either be
UniqueConstraintViolation if the table has any unique constraints, or Infallible
otherwise.Sourcetype AutoIncOverflow = Infallible
type AutoIncOverflow = Infallible
The error type for this table for auto-increment overflows. Will either be
AutoIncOverflow if the table has any auto-incrementing columns, or Infallible
otherwise.Sourcefn iter(&self) -> impl Iterator<Item = Self::Row>
fn iter(&self) -> impl Iterator<Item = Self::Row>
Iterate over all rows of the table. Read more
Sourcefn try_insert(&self, row: Self::Row) -> Result<Self::Row, TryInsertError<Self>>
fn try_insert(&self, row: Self::Row) -> Result<Self::Row, TryInsertError<Self>>
Counterpart to
Self::insert which allows handling failed insertions. Read moreAuto Trait Implementations
impl Freeze for user__TableHandle
impl RefUnwindSafe for user__TableHandle
impl Send for user__TableHandle
impl Sync for user__TableHandle
impl Unpin for user__TableHandle
impl UnsafeUnpin for user__TableHandle
impl UnwindSafe for user__TableHandle